@@ -1,7 +1,8 @@
 from datetime import datetime
 from typing import List, Optional, Dict, Any, Literal
 from plato.config import get_config
-from plato.models import PlatoTask, PlatoEnvironment
+from plato.models import PlatoTask, PlatoTaskMetadata, PlatoEnvironment
+from plato.models.task import ScoringType
 from plato.exceptions import PlatoClientError
 from plato.models.task import EvaluationResult
 
@@ -79,7 +80,11 @@ class Plato:
             try:
                 # Try to get the error message from the response body
                 error_data = await response.json()
-                error_message = error_data.get('error') or error_data.get('message') or str(error_data)
+                error_message = (
+                    error_data.get("error")
+                    or error_data.get("message")
+                    or str(error_data)
+                )
             except (aiohttp.ContentTypeError, ValueError):
                 # Fallback to status text if we can't parse JSON
                 error_message = response.reason or f"HTTP {response.status}"
@@ -92,7 +97,7 @@ class Plato:
         open_page_on_start: bool = False,
         viewport_width: int = 1920,
         viewport_height: int = 1080,
-        interface_type: Optional[Literal["browser"]] = "browser",
+        interface_type: Optional[str] = None,
         record_network_requests: bool = False,
         record_actions: bool = False,
         env_config: Optional[Dict[str, Any]] = None,
@@ -100,6 +105,10 @@ class Plato:
         alias: Optional[str] = None,
         fast: bool = False,
         version: Optional[str] = None,
+        tag: Optional[str] = None,
+        dataset: Optional[str] = None,
+        artifact_id: Optional[str] = None,
+        feature_flags: Optional[Dict[str, Any]] = None,
     ) -> PlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -133,6 +142,9 @@ class Plato:
                 "source": "SDK",
                 "open_page_on_start": open_page_on_start,
                 "env_id": env_id,
+                "tag": tag,
+                "dataset": dataset,
+                "artifact_id": artifact_id,
                 "env_config": env_config or {},
                 "record_network_requests": record_network_requests,
                 "record_actions": record_actions,
@@ -141,6 +153,7 @@ class Plato:
                 "fast": fast,
                 "version": version,
             },
+            cookies={name: str(value) for name, value in (feature_flags or {}).items()},
             headers=headers,
         ) as response:
             await self._handle_response_error(response)
@@ -195,6 +208,21 @@ class Plato:
                 raise PlatoClientError(data["error"])
             return data["data"]["cdp_url"]
 
+    async def get_proxy_url(self, job_id: str) -> str:
+        """Get the proxy URL for a job.
+
+        Args:
+            job_id (str): The ID of the job to get the proxy URL for.
+        """
+        headers = {"X-API-Key": self.api_key}
+        async with self.http_session.get(
+            f"{self.base_url}/env/{job_id}/proxy_url", headers=headers
+        ) as response:
+            data = await response.json()
+            if data["error"] is not None:
+                raise PlatoClientError(data["error"])
+            return data["data"]["proxy_url"]
+
     async def close_environment(self, job_id: str) -> Dict[str, Any]:
         """Close an environment.
 
@@ -271,7 +299,9 @@ class Plato:
             await self._handle_response_error(response)
             return await response.json()
 
-    async def get_environment_state(self, job_id: str) -> Dict[str, Any]:
+    async def get_environment_state(
+        self, job_id: str, merge_mutations: bool = False
+    ) -> Dict[str, Any]:
         """Get the current state of an environment.
 
         Args:
@@ -285,7 +315,9 @@ class Plato:
         """
         headers = {"X-API-Key": self.api_key}
         async with self.http_session.get(
-            f"{self.base_url}/env/{job_id}/state", headers=headers
+            f"{self.base_url}/env/{job_id}/state",
+            headers=headers,
+            params={"merge_mutations": str(merge_mutations).lower()},
         ) as response:
             await self._handle_response_error(response)
             data = await response.json()
@@ -380,17 +412,27 @@ class Plato:
             return await response.json()
 
     async def evaluate(
-        self, session_id: str, agent_version: Optional[str] = None
+        self,
+        session_id: str,
+        value: Optional[Any] = None,
+        agent_version: Optional[str] = None,
     ) -> Dict[str, Any]:
         """Evaluate the environment.
 
         Args:
             session_id (str): The ID of the session to evaluate.
+            value (Optional[Any]): Optional value to include in the evaluation request.
+            agent_version (Optional[str]): Optional agent version.
         """
         headers = {"X-API-Key": self.api_key}
+        body = {}
+        if value is not None:
+            body = {"value": value}
+
         async with self.http_session.post(
             f"{self.base_url}/env/session/{session_id}/evaluate",
             headers=headers,
+            json=body,
         ) as response:
             await self._handle_response_error(response)
             res_data = await response.json()
@@ -485,8 +527,23 @@ class Plato:
                     env_id=t["simulator"]["name"],
                     average_time=t.get("averageTimeTaken"),
                     average_steps=t.get("averageStepsTaken"),
-                    num_validator_human_scores=t.get("defaultScoringConfig", {}).get("num_sessions_used", 0),
+                    num_validator_human_scores=t.get("defaultScoringConfig", {}).get(
+                        "num_sessions_used", 0
+                    ),
                     default_scoring_config=t.get("defaultScoringConfig", {}),
+                    scoring_type=[ScoringType(st) for st in t.get("scoringTypes", [])]
+                    if t.get("scoringTypes")
+                    else None,
+                    output_schema=t.get("outputSchema"),
+                    is_sample=t.get("isSample", False),
+                    simulator_artifact_id=t.get("simulatorArtifactId"),
+                    metadata=PlatoTaskMetadata(
+                        reasoning_level=t.get("metadataConfig", {}).get("reasoningLevel"),
+                        skills=t.get("metadataConfig", {}).get("skills", []),
+                        capabilities=t.get("metadataConfig", {}).get("capabilities", []),
+                        tags=t.get("metadataConfig", {}).get("tags", []),
+                        rejected=t.get("metadataConfig", {}).get("rejected", False),
+                    ) if t.get("metadataConfig") else None,
                 )
                 for t in test_cases
             ]
@@ -554,13 +611,13 @@ class Plato:
             return await response.json()
 
     # Gitea-related methods for hub commands
-    
+
     async def get_gitea_info(self) -> Dict[str, Any]:
         """Get the current user's Gitea info (auto-provisions if needed).
-        
+
         Returns:
             Dict[str, Any]: User's Gitea information including username and org_name.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
             PlatoClientError: If user doesn't have admin access.
@@ -571,13 +628,13 @@ class Plato:
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-    
+
     async def list_gitea_simulators(self) -> List[Dict[str, Any]]:
         """Get simulators that user has access to view repos for.
-        
+
         Returns:
             List[Dict[str, Any]]: List of simulators with repository info.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
         """
@@ -587,16 +644,16 @@ class Plato:
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-    
+
     async def get_simulator_repository(self, simulator_id: int) -> Dict[str, Any]:
         """Get repository details for a specific simulator.
-        
+
         Args:
             simulator_id (int): The ID of the simulator to get repository info for.
-            
+
         Returns:
             Dict[str, Any]: Repository information for the simulator.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
             PlatoClientError: If simulator not found or access denied.
@@ -607,13 +664,13 @@ class Plato:
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-    
+
     async def get_gitea_credentials(self) -> Dict[str, Any]:
         """Get Gitea admin credentials for the organization.
-        
+
         Returns:
             Dict[str, Any]: Gitea credentials including username and password.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
             PlatoClientError: If user doesn't have access.
@@ -624,24 +681,26 @@ class Plato:
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-    
-    async def create_simulator(self, name: str, description: str = None, sim_type: str = "docker_app") -> Dict[str, Any]:
+
+    async def create_simulator(
+        self, name: str, description: str = None, sim_type: str = "docker_app"
+    ) -> Dict[str, Any]:
         """Create a new simulator.
-        
+
         Args:
             name (str): The name of the simulator
             description (str, optional): Description of the simulator
             sim_type (str, optional): Type of simulator (default: docker_app)
-            
+
         Returns:
             Dict[str, Any]: Created simulator information.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
             PlatoClientError: If creation fails.
         """
         headers = {"X-API-Key": self.api_key}
-        
+
         # Basic simulator configuration
         simulator_data = {
             "name": name,
@@ -651,36 +710,32 @@ class Plato:
             "config": {
                 "image_name": f"plato-{name}:latest",
                 "internal_app_port": 80,
-                "supported_providers": ["ecs_service", "ecs_task"]
-            }
+                "supported_providers": ["ecs_service", "ecs_task"],
+            },
         }
-        
+
         async with self.http_session.post(
-            f"{self.base_url}/env/simulators",
-            json=simulator_data,
-            headers=headers
+            f"{self.base_url}/env/simulators", json=simulator_data, headers=headers
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-    
+
     async def create_simulator_repository(self, simulator_id: int) -> Dict[str, Any]:
         """Create a repository for a simulator.
-        
+
         Args:
             simulator_id (int): The ID of the simulator to create repository for.
-            
+
         Returns:
             Dict[str, Any]: Created repository information.
-            
+
         Raises:
             aiohttp.ClientError: If the API request fails.
             PlatoClientError: If creation fails.
         """
         headers = {"X-API-Key": self.api_key}
         async with self.http_session.post(
-            f"{self.base_url}/gitea/simulators/{simulator_id}/repo",
-            headers=headers
+            f"{self.base_url}/gitea/simulators/{simulator_id}/repo", headers=headers
         ) as response:
             await self._handle_response_error(response)
             return await response.json()
-
