@@ -64,11 +64,13 @@ class SyncPlatoEnvironment:
 
     # No embedded defaults; expect scripts.yaml to exist in repo at plato/flows/{env_id}/scripts.yaml
 
-    def login(self, page: Page, throw_on_login_error: bool = False) -> None:
+    def login(self, page: Page, throw_on_login_error: bool = False, dataset: str = "base") -> None:
         """Login to the environment using authentication config.
 
         Args:
             page (Page): The Playwright page to authenticate
+            throw_on_login_error (bool): Whether to raise an error on login failure
+            dataset (str): The dataset to use for login (default: "base")
         """
         from plato.models.flow import Simulator
         from plato.sync_flow_executor import SyncFlowExecutor
@@ -86,20 +88,26 @@ class SyncPlatoEnvironment:
             scripts = yaml.safe_load(f)
         simulator = Simulator.model_validate(scripts)
 
-        # Get base dataset and login flow
-        base_dataset = next(
-            (dataset for dataset in simulator.datasets if dataset.name == "base"), None
+        # Get the specified dataset
+        target_dataset = next(
+            (d for d in simulator.datasets if d.name == dataset), None
         )
-        if not base_dataset:
-            raise PlatoClientError("No base dataset found")
+        if not target_dataset:
+            raise PlatoClientError(f"No dataset '{dataset}' found")
+
+        # Determine flow name based on dataset
+        if dataset == "base":
+            flow_name = "login"
+        else:
+            flow_name = dataset
 
         login_flow = next(
-            (flow for flow in simulator.flows if flow.name == "login"), None
+            (flow for flow in simulator.flows if flow.name == flow_name), None
         )
         if not login_flow:
-            raise PlatoClientError("No login flow found")
+            raise PlatoClientError(f"No login flow '{flow_name}' found")
 
-        flow_executor = SyncFlowExecutor(page, login_flow, base_dataset, logger=logger)
+        flow_executor = SyncFlowExecutor(page, login_flow, target_dataset, logger=logger)
         if not flow_executor.execute_flow():
             if throw_on_login_error:
                 raise PlatoClientError("Failed to login")
@@ -287,7 +295,7 @@ class SyncPlatoEnvironment:
             )  # Wait up to 5 seconds for thread to stop
             self._heartbeat_thread = None
 
-    def get_state(self) -> Dict[str, Any]:
+    def get_state(self, merge_mutations: bool = False) -> Dict[str, Any]:
         """Get the current state of the environment.
 
         Returns:
@@ -298,9 +306,11 @@ class SyncPlatoEnvironment:
         """
         if not self._run_session_id:
             raise PlatoClientError("No active run session. Call reset() first.")
-        return self._client.get_environment_state(self.id)
+        return self._client.get_environment_state(self.id, merge_mutations)
 
-    def get_state_mutations(self) -> List[Dict[str, Any]]:
+    def get_state_mutations(
+        self, merge_mutations: bool = False
+    ) -> List[Dict[str, Any]]:
         """Get a list of state mutations that have occurred in the environment.
 
         Returns:
@@ -309,7 +319,7 @@ class SyncPlatoEnvironment:
         Raises:
             PlatoClientError: If no active run session exists.
         """
-        state = self.get_state()
+        state = self.get_state(merge_mutations)
         return state.get("mutations", [])
 
     def _get_nested_value(self, data: Dict[str, Any], key_path: str) -> Any:
@@ -394,10 +404,11 @@ class SyncPlatoEnvironment:
                 success=False, reason=f"Unknown evaluation type: {eval_config.type}"
             )
 
-    def evaluate(self, agent_version: Optional[str] = None) -> EvaluationResult:
+    def evaluate(self, value: Optional[Any] = None, agent_version: Optional[str] = None) -> EvaluationResult:
         """Evaluate the current task.
 
         Args:
+            value (Optional[Any]): Optional value to include in the evaluation request.
             agent_version (Optional[str]): Optional agent version.
 
         Returns:
@@ -423,7 +434,7 @@ class SyncPlatoEnvironment:
             return evaluation_result
         else:
             # call /evaluate endpoint
-            response = self._client.evaluate(self._run_session_id, agent_version)
+            response = self._client.evaluate(self._run_session_id, value, agent_version)
             if not response:
                 raise PlatoClientError("No evaluation result found")
             result = response["result"]
@@ -483,23 +494,25 @@ class SyncPlatoEnvironment:
             if not worker_status.get("ready"):
                 raise PlatoClientError("Worker is not ready yet")
 
-            # Extract the base domain from the base_url
-            if "localhost:8080" in self._client.base_url:
-                proxy_server = "http://localhost:8888"
-            elif "plato.so" in self._client.base_url:
-                # Extract domain from base_url to construct proxy server URL
-                parsed_url = urlparse(self._client.base_url)
-                domain_parts = parsed_url.netloc.split('.')
+            try:
+                proxy_server = self._client.get_proxy_url(self.id)
+            except Exception as e:
+                logger.error(f"Error getting proxy URL: {e}")
+                # Extract the base domain from the base_url
+                if "localhost:8080" in self._client.base_url:
+                    proxy_server = "http://localhost:8888"
+                elif "plato.so" in self._client.base_url:
+                    # Extract domain from base_url to construct proxy server URL
+                    parsed_url = urlparse(self._client.base_url)
+                    domain_parts = parsed_url.netloc.split('.')
 
-                # Check if there's a subdomain before "plato.so"
-                if len(domain_parts) >= 3 and domain_parts[-2:] == ['plato', 'so']:
-                    subdomain = domain_parts[0]
-                    proxy_server = f"https://{subdomain}.proxy.plato.so"
-                else:
-                    # No subdomain, use just proxy.plato.so
-                    proxy_server = "https://proxy.plato.so"
-            else:
-                raise PlatoClientError("Unknown base URL")
+                    # Check if there's a subdomain before "plato.so"
+                    if len(domain_parts) >= 3 and domain_parts[-2:] == ['plato', 'so']:
+                        subdomain = domain_parts[0]
+                        proxy_server = f"https://{subdomain}.proxy.plato.so"
+                    else:
+                        # No subdomain, use just proxy.plato.so
+                        proxy_server = "https://proxy.plato.so"
 
             return {
                 "server": proxy_server,
