@@ -1,7 +1,8 @@
 from datetime import datetime
 from typing import List, Optional, Dict, Any, Literal
 from plato.config import get_config
-from plato.models import PlatoTask
+from plato.models import PlatoTask, PlatoTaskMetadata
+from plato.models.task import ScoringType
 from plato.exceptions import PlatoClientError
 from plato.models.task import EvaluationResult
 from plato.sync_env import SyncPlatoEnvironment
@@ -11,6 +12,7 @@ import logging
 import time
 import requests
 
+
 logger = logging.getLogger(__name__)
 
 config = get_config()
@@ -70,7 +72,11 @@ class SyncPlato:
             try:
                 # Try to get the error message from the response body
                 error_data = response.json()
-                error_message = error_data.get('error') or error_data.get('message') or str(error_data)
+                error_message = (
+                    error_data.get("error")
+                    or error_data.get("message")
+                    or str(error_data)
+                )
             except (ValueError, requests.exceptions.JSONDecodeError):
                 # Fallback to status text if we can't parse JSON
                 error_message = response.reason or f"HTTP {response.status_code}"
@@ -83,7 +89,7 @@ class SyncPlato:
         open_page_on_start: bool = False,
         viewport_width: int = 1920,
         viewport_height: int = 1080,
-        interface_type: Optional[Literal["browser"]] = "browser",
+        interface_type: Optional[str] = None,
         record_network_requests: bool = False,
         record_actions: bool = False,
         env_config: Optional[Dict[str, Any]] = None,
@@ -91,6 +97,10 @@ class SyncPlato:
         alias: Optional[str] = None,
         fast: bool = False,
         version: Optional[str] = None,
+        tag: Optional[str] = None,
+        dataset: Optional[str] = None,
+        artifact_id: Optional[str] = None,
+        feature_flags: Optional[Dict[str, Any]] = None,
     ) -> SyncPlatoEnvironment:
         """Create a new Plato environment for the given task.
 
@@ -130,7 +140,11 @@ class SyncPlato:
                 "alias": alias,
                 "fast": fast,
                 "version": version,
+                "tag": tag,
+                "dataset": dataset,
+                "artifact_id": artifact_id,
             },
+            cookies={name: str(value) for name, value in (feature_flags or {}).items()},
         )
         self._handle_response_error(response)
         data = response.json()
@@ -179,6 +193,25 @@ class SyncPlato:
             raise PlatoClientError(data["error"])
         return data["data"]["cdp_url"]
 
+    def get_proxy_url(self, job_id: str) -> str:
+        """Get the proxy URL for a job.
+
+        Args:
+            job_id (str): The ID of the job to get the proxy URL for.
+
+        Returns:
+            str: The proxy URL for the job.
+
+        Raises:
+            PlatoClientError: If the API request fails or returns an error.
+            requests.RequestException: If the API request fails.
+        """
+        response = self.http_session.get(f"{self.base_url}/env/{job_id}/proxy_url")
+        data = response.json()
+        if data["error"] is not None:
+            raise PlatoClientError(data["error"])
+        return data["data"]["proxy_url"]
+
     def close_environment(self, job_id: str) -> Dict[str, Any]:
         """Close an environment.
 
@@ -249,11 +282,14 @@ class SyncPlato:
         self._handle_response_error(response)
         return response.json()
 
-    def get_environment_state(self, job_id: str) -> Dict[str, Any]:
+    def get_environment_state(
+        self, job_id: str, merge_mutations: bool = False
+    ) -> Dict[str, Any]:
         """Get the current state of an environment.
 
         Args:
             job_id (str): The ID of the job to get state for.
+            merge_mutations (bool): Whether to merge mutations into the state.
 
         Returns:
             Dict[str, Any]: The current state of the environment.
@@ -261,7 +297,10 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
-        response = self.http_session.get(f"{self.base_url}/env/{job_id}/state")
+        response = self.http_session.get(
+            f"{self.base_url}/env/{job_id}/state",
+            params={"merge_mutations": str(merge_mutations).lower()},
+        )
         self._handle_response_error(response)
         data = response.json()
         return data["data"]["state"]
@@ -332,15 +371,23 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
-        response = self.http_session.post(f"{self.base_url}/snapshot/process/{session_id}")
+        response = self.http_session.post(
+            f"{self.base_url}/snapshot/process/{session_id}"
+        )
         self._handle_response_error(response)
         return response.json()
 
-    def evaluate(self, session_id: str, agent_version: Optional[str] = None) -> Dict[str, Any]:
+    def evaluate(
+        self,
+        session_id: str,
+        value: Optional[Any] = None,
+        agent_version: Optional[str] = None,
+    ) -> Dict[str, Any]:
         """Evaluate the environment.
 
         Args:
             session_id (str): The ID of the session to evaluate.
+            value (Optional[Any]): Optional value to include in the evaluation request.
             agent_version (Optional[str]): Optional agent version.
 
         Returns:
@@ -349,8 +396,13 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
+        body = {}
+        if value is not None:
+            body = {"value": value}
+
         response = self.http_session.post(
             f"{self.base_url}/env/session/{session_id}/evaluate",
+            json=body,
         )
         self._handle_response_error(response)
         res_data = response.json()
@@ -457,8 +509,23 @@ class SyncPlato:
                 env_id=t["simulator"]["name"],
                 average_time=t.get("averageTimeTaken"),
                 average_steps=t.get("averageStepsTaken"),
-                num_validator_human_scores=t.get("defaultScoringConfig", {}).get("num_sessions_used", 0),
+                num_validator_human_scores=t.get("defaultScoringConfig", {}).get(
+                    "num_sessions_used", 0
+                ),
                 default_scoring_config=t.get("defaultScoringConfig", {}),
+                scoring_type=[ScoringType(st) for st in t.get("scoringTypes", [])]
+                if t.get("scoringTypes")
+                else None,
+                output_schema=t.get("outputSchema"),
+                is_sample=t.get("isSample", False),
+                simulator_artifact_id=t.get("simulatorArtifactId"),
+                metadata=PlatoTaskMetadata(
+                    reasoning_level=t.get("metadataConfig", {}).get("reasoningLevel"),
+                    skills=t.get("metadataConfig", {}).get("skills", []),
+                    capabilities=t.get("metadataConfig", {}).get("capabilities", []),
+                    tags=t.get("metadataConfig", {}).get("tags", []),
+                    rejected=t.get("metadataConfig", {}).get("rejected", False),
+                ) if t.get("metadataConfig") else None,
             )
             for t in test_cases
         ]
@@ -492,6 +559,8 @@ class SyncPlato:
         Raises:
             requests.RequestException: If the API request fails.
         """
-        response = self.http_session.get(f"{self.base_url}/user/organization/running-sessions")
+        response = self.http_session.get(
+            f"{self.base_url}/user/organization/running-sessions"
+        )
         self._handle_response_error(response)
         return response.json()
